Coverage for pygeodesy/deprecated/nvector.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''DEPRECATED on 2021.05.20, use (INTERNAL) module L{pygeodesy.nvectorBase} instead.

5'''

6

7# from pygeodesy.interns import NN # from .lazily

8 from pygeodesy.lazily import _ALL_DEPRECATED, _ALL_OTHER, NN

9 from pygeodesy.nvectorBase import LatLonNvectorBase, NorthPole, NvectorBase, \

10 SouthPole, sumOf

11 from pygeodesy.props import deprecated_class

12

13 __all__ = _ALL_DEPRECATED.deprecated_nvector

14 __version__ = '23.11.26'

15

16

17 class Nvector(NvectorBase): # PYCHOK no cover

18 '''DEPRECATED on 2021.05.20, see (INTERNAL) class L{pygeodesy.nvectorBase.NvectorBase}.

19 '''

20 def __init__(self, x, y=None, z=None, h=0, ll=None, datum=None, name=NN):

21 deprecated_class(self.__class__)

22 NvectorBase.__init__(self, x, y=y, z=z, h=h, ll=ll, datum=datum, name=name)

23

24

25 assert (_ALL_OTHER(LatLonNvectorBase, Nvector, sumOf) +

26 (NorthPole.name, SouthPole.name)) == __all__

27

28# **) MIT License

29#

30# Copyright (C) 2016-2026 -- mrJean1 at Gmail -- All Rights Reserved.

31#

32# Permission is hereby granted, free of charge, to any person obtaining a

33# copy of this software and associated documentation files (the "Software"),

34# to deal in the Software without restriction, including without limitation

35# the rights to use, copy, modify, merge, publish, distribute, sublicense,

36# and/or sell copies of the Software, and to permit persons to whom the

37# Software is furnished to do so, subject to the following conditions:

38#

39# The above copyright notice and this permission notice shall be included

40# in all copies or substantial portions of the Software.

41#

42# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

43# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

44# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

45# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

46# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

47# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

48# OTHER DEALINGS IN THE SOFTWARE.